Looks for duplicated edges and reports the number of instances of them.
Details
check.dpl.edges looks for duplicated edges reporting duplicates and
counting how many times each edge is duplicated.
For every group of duplicated edges only one will be accounted to report
number of instances (which will be recognized with a value higher than 2 in
the reps column), the other ones will be assigned an NA at the
reps value.
See also
Other manipulation:
switch.edges()
Examples
# An edgelist with duplicated dyads
relations <- cbind(c(1,1,3,3,4,2,5,6), c(2,3,1,1,2,4,1,1))
# Checking duplicated edges (undirected graph)
check.dpl.edges(edges=relations, undirected=TRUE)
#> source target reps
#> 1 1 2 1
#> 2 1 3 NA
#> 3 3 1 NA
#> 4 3 1 3
#> 5 4 2 NA
#> 6 2 4 2
#> 7 5 1 1
#> 8 6 1 1