Creates an htmlwidget that renders a GEXF file using the bundled gexf-js library.
gexfjs(
gexf = system.file("gexf-graphs/lesmiserables.gexf", package = "rgexf"),
width = "100%",
height = "400px"
)gexfjsOutput(outputId, width = "100%", height = "400px")
renderGexfjs(expr, env = parent.frame(), quoted = FALSE)
An htmlwidget object.
Either a gexf object, or a path to a .gexf file. Defaults
to the bundled Les Miserables example.
Widget dimensions. Default to "100%" width and
"400px" height, so the widget spans the full available width.
Shiny output ID.
An expression that returns a gexfjs widget.
The environment in which to evaluate expr.
Logical scalar. Is expr a quoted expression?